//--------------------------------------------------------------------
//--------------------------------------------------------------------
//--------------------------------------------------------------------

   /*


	Classname   :  rmBlinker.cc

   Version     :  1.06.0105

   Date        :  Jan 2006


   For         :  dBASE Plus / dB2K / Win9x / NT / Win2000 / WinXP


   Author      :  Ronnie MacGregor

   Contact     :  rmBlinkerFeedback@dBASEdeveloper.co.uk

   Copyright   :  Ronnie MacGregor   All rights reserved.


   Disclaimer  :  It is the duty of the user of this code to determine its 
                  suitability for use.

                  The use of this code signifies agreement to the following
                  condition of use.
                  
                  In no circumstance will the author accept any responsibility
                  for any consequence arising from the use of this code.


   Description :  A Custom timer which can be used to "blink" form objects.

                  To check that you have the latest version of this control
                  go to:

                     www.dBASEdeveloper.co.uk 


   Useage      :  Create an instance of the timer in your form's onOpen()

                     function MyForm_OnOpen()

                     // Create rmBlinker
                     set procedure to rmBlinker.cc additive
                     this.rmBlinker = new rmBlinker()

                  See rmBlinker.wfm for demo and example code.


   Dependancies:

      None.


   Acknowledgements:

      None.


   Revisions:

      None.


   */

//--------------------------------------------------------------------
//--------------------------------------------------------------------
//--------------------------------------------------------------------

class rmBlinker(oP) of Timer() custom   

   // Stock properties
   this.interval = 0.5
   this.enabled = false

   // Custom properties
   this.aObjectRefs = new array()
   this.StartTime = 0
   this.FlashCount = 0

   //-------------------

   function StartBlinking(oRef)

      local nCount, bFound

      // Add object to array if not already there
      bFound = false
      for nCount = 1 to this.aObjectRefs.size
         if this.aObjectRefs[nCount] == oRef
            bFound = true
            exit
         endif
      endfor // next
      if bFound == false
         this.aObjectRefs.add(oRef)
      endif

      // Synchronise with any existing blinking objects
      if this.aObjectRefs.size > 1
         oRef.visible := this.aObjectRefs[1].visible
      endif

      // Start timer if not already running
      if this.enabled == false
         this.enabled := true
      endif

   return

   //-------------------

   function StopBlinking(oRef)

      local nCount, bFound

      // Remove object from array if there
      bFound = false
      for nCount = 1 to this.aObjectRefs.size
         if this.aObjectRefs[nCount] == oRef
            bFound = true
            exit
         endif
      endfor // next
      if bFound == true
         this.aObjectRefs.delete(nCount)
         this.aObjectRefs.size := this.aObjectRefs.size -1
      endif

      // Stop timer if no objects left in array
      if this.aObjectRefs.size == 0
         this.enabled := false
      endif

      // Ensure that the referenced control is left visible
      oRef.visible := true

   return

   //-------------------

   function onTimer()

      local nCount

      // Blink all listed controls
      for nCount = 1 to this.aObjectRefs.size
         this.aObjectRefs[nCount].visible := not this.aObjectRefs[nCount].visible
      endfor // next
        
   return
   
   //-------------------
      
endclass

//--------------------------------------------------------------------
//--------------------------------------------------------------------
//--------------------------------------------------------------------

   /*


	Classname   :  rmLoopBlinker.cc

   Version     :  1.06.0105

   Date        :  Jan 2006


   For         :  dBASE Plus / dB2K / Win9x / NT / Win2000 / WinXP


   Author      :  Ronnie MacGregor

   Contact     :  rmLoopBlinkerFeedback@dBASEdeveloper.co.uk

   Copyright   :  Ronnie MacGregor   All rights reserved.


   Disclaimer  :  It is the duty of the user of this code to determine its 
                  suitability for use.

                  The use of this code signifies agreement to the following
                  condition of use.
                  
                  In no circumstance will the author accept any responsibility
                  for any consequence arising from the use of this code.


   Description :  A Custom control which can be used to "blink" form objects
                  while processing in a loop.

                  To check that you have the latest version of this control
                  go to:

                     www.dBASEdeveloper.co.uk 


   Useage      :  Create an instance of the timer in your form's onOpen()

                     function MyForm_OnOpen()

                     // Create rmLoopBlinker
                     set procedure to rmBlinker.cc additive
                     this.rmLoopBlinker = new rmLoopBlinker(oP)

                  See rmBlinker.wfm for demo and example code.


   Dependancies:

      None.


   Acknowledgements:

      None.


   Revisions:

      None.


   */

//--------------------------------------------------------------------
//--------------------------------------------------------------------
//--------------------------------------------------------------------

class rmLoopBlinker(oP) of PaintBox(oP) custom   

   // Stock properties
   this.visible = false

   // Custom properties
   this.aObjectRefs = new array()
   this.interval = 0.5

   //-------------------

   function AddBLinkObject(oRef)

      local nCount, bFound

      // Add object to array if not already there
      bFound = false
      for nCount = 1 to this.aObjectRefs.size
         if this.aObjectRefs[nCount] == oRef
            bFound = true
            exit
         endif
      endfor // next
      if bFound == false
         this.aObjectRefs.add(oRef)
      endif

   return

   //-------------------

   function DeleteBLinkObject(oRef)

      local nCount, bFound

      // Remove object from array if there
      bFound = false
      for nCount = 1 to this.aObjectRefs.size
         if this.aObjectRefs[nCount] == oRef
            bFound = true
            exit
         endif
      endfor // next
      if bFound == true
         this.aObjectRefs.delete(nCount)
         this.aObjectRefs.size := this.aObjectRefs.size -1
      endif

      // Ensure that the referenced control is left visible
      oRef.visible := true

   return


   //-------------------

   function StartBlinking()

      this.StartTime = seconds()
      this.FlashCount = 0

   return

   //-------------------

   function StopBlinking()

      // Ensure controls are left visible
      for nCount = 1 to this.aObjectRefs.size
         this.aObjectRefs[nCount].visible := true
      endfor // next

   return

   //-------------------

   function Blink()

      local nCount, nLapse

      // Do the blinking 
      nLapse = int((seconds() - this.StartTime) * 10)
      if nLapse > this.FlashCount
         // Update FlashCount
         this.FlashCount = this.FlashCount + (this.Interval * 10)
         // Blink all listed controls
         for nCount = 1 to this.aObjectRefs.size
            this.aObjectRefs[nCount].visible := not this.aObjectRefs[nCount].visible
         endfor // next         
         // Force repaint
         _app.executeMessages( ) 
      endif

   return

   //-------------------

endclass

//--------------------------------------------------------------------
//--------------------------------------------------------------------
//--------------------------------------------------------------------

// eof
